package com.me.asteroids.systems;

import com.badlogic.gdx.math.Rectangle;
import com.badlogic.gdx.math.Vector2;
import com.me.asteroids.Constants;
import com.me.asteroids.components.ModelComponent;
import com.me.asteroids.components.PositionComponent;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class ScreenWrapSystem extends EntitySystem {

    public ScreenWrapSystem() {
        super(PositionComponent.class, ModelComponent.class);
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        PositionComponent positionComponent = entity.getComponent(PositionComponent.class);
        ModelComponent modelComponent = entity.getComponent(ModelComponent.class);

        Vector2 position = positionComponent.position;
        Rectangle aabb = modelComponent.aabb;

        // Check top/bottom edges
        float minY = aabb.y;
        float maxY = minY + aabb.height;
        if (minY > Constants.HEIGHT) {
            position.y = (position.y - maxY) + (minY - Constants.HEIGHT);
            return;
        } else if (maxY < 0) {
            position.y = Constants.HEIGHT + (position.y - minY) + maxY;
            return;
        }

        // Check right/left edges
        float minX = aabb.x;
        float maxX = minX + aabb.width;
        if (maxX < 0) {
            position.x = Constants.WIDTH + (position.x - minX) + maxX;
        }  else if (minX > Constants.WIDTH) {
            position.x = (position.x - maxX) + (minX - Constants.WIDTH);

        }
    }

}
